import { currency, iosDateFormat, toPercent } from "@/utils/textFormat"
import { watch } from "vue"

const formItemTemplate = {
  value: '',
  title: '', //名称
  propName: '',
  placeHolder: '',

  type: '', // cell/input 或其他，看变化,
  select: '', // String | Array | date 指定类型，或者 直接给列表
  disabled: false, //能否填写该表单
  isRequired: true, // 是否必须
  // validateRes: true //校验结果
}

const attrArr = ['value', 'title', 'propName', 'placeHolder', 'type', 'select', 'disabled', 'isRequired', 'validateRes']

export default class AuFormClass {
  form = []

  constructor(rawArray = [], config = {}) { //config 应该是一个rawArray 里 propName 对应的键值对
    this.replace(rawArray, config)
  }

  get value() {
    return this.form
  }

  // 替换 form 元素
  replace(rawArray = [], config = {}) {
    if (!rawArray.length) return false
    this.form = this.fillForm(rawArray, config)
  }

  // 添加 form 元素
  AddFormItem(rawArray = [], config = {}) {
    if (!rawArray.length) return false
    this.form = [...this.form, ...this.fillForm(rawArray, config)]
  }


  // 得到一个只有 propName 和 value 的对象
  getValues(needOther = false) {
    if (!needOther) {
      return this.form.reduce((valList, formItem) => {
        let { propName, value, type } = formItem

        let returnValue = value
        if (type === 'currency') returnValue = value.replace(/[,]*/g, '')
        if (type === 'rate') returnValue = (+value / 100)

        if (type === 'checkGroup') {
          let checkRes = {}
          formItem.checkList.forEach(checkItem => {
            formItem.getCb(checkRes, checkItem, value)
          })
          valList = { ...valList, ...checkRes }
          return valList
        }

        valList[propName] = returnValue
        return valList
      }, {})
    } else {
      return this.form.reduce((valList, item) => {
        let { propName, value, type } = item
        let returnValue = value
        if (type === 'currency') returnValue = value.replace(/[,]*/g, '')
        // valList[propName] = { ...item, value: returnValue }
        valList.push({ ...item, value: returnValue })
        return valList
      }, [])
    }
  }

  // 设置全部的某一个属性
  setAll(attribute, cb) {
    this.form.forEach(item => {
      item[attribute] = cb(item)
    })
  }

  // 把对象中有的值填充进来
  fillValues(obj = {}) {
    this.form.forEach(item => {
      if (item.propName in obj) {
        let outSideValue = obj[item.propName] || ""

        if (item.select === 'date') {
          item.value = outSideValue ? iosDateFormat(outSideValue).toLocaleDateString() : ''
        }

        else if (item.type === 'checkGroup') {
          let value = []
          item.checkList.forEach(({ checkProp }) => {
            if (customer.hasOwnProperty(checkProp))
              !!obj[checkProp] ? value.push(checkProp) : null;
          })
          item.value = value;
        }

        else if (item.type === 'currency') {
          item.value = currency((outSideValue + '').replace(/[^0-9.]*/g, ''))
        }

        else if (item.type === 'rate') {
          item.value = toPercent(+outSideValue, false)
        }

        else {
          item.value = outSideValue
        }
      }
    })
  }

  // 设置某一个属性的值
  setFormValue(propName, attribute, value) {
    if (!propName || value === undefined || value === null) return false
    let obj = this.getFormValue(propName, true)

    if (!obj) return false
    return obj[attribute] = value
  }

  // 清空表单的值
  clearForm() {
    this.form = this.form.map(item => {
      let value = ''
      if (item.type === 'checkGroup') value = []
      return { ...item, value }
    })
  }

  // 取某一个属性的值, outObj 决定返回是一个对象还是 一个值， 默认为值
  getFormValue(propName, outObj = false) {
    let formItem = this.form.find(item => item.propName === propName);
    if (formItem) return outObj ? formItem : formItem.value
  }

  // 监听表单的值
  watchForm(targetPropName, cb, watchConfig = {}) {
    watch(() => this.getFormValue(targetPropName), (n, o) => { cb(n, o) }, watchConfig)
  }

  // 补齐表单每一个子项
  fillForm(formArr, config = {}) {
    return formArr.map(item => ({ ...formItemTemplate, ...item, ...config }))
  }

  // 检验是否通过, 通过返回 true ，若不通过，会给没通过的项添加 validateRes = true
  validate() {
    let res = true
    this.form = this.form.map(item => {
      let { isRequired, value } = item

      if (item.type === 'checkGroup') {
        item.validateRes = isRequired && !value.length;
      } else {
        item.validateRes = isRequired && !(value + '')
      }

      // 用正则表达式检验
      if (item.reg && !item.validateRes && value ) {
        let res = item.reg.test(value)
        if (!res) item.validateRes = true
      }

      if (item.validateRes && res) res = false
      return item
    })
    return res
  }
}
