/**
 * 一些帮助函数
 * @author momoko
 */

/**
 * 取URL上的参数
 * @param  {String} param 参数名
 * @return {String}
 */
export function getUrlParam(param) {
  const result = window.location.href.match(new RegExp('(\\?|&)' + param + '(\\[\\])?=([^&#]*)'))
  return result ? result[3] : undefined
}

/**
 * 动态插入 script to html
 * @param url
 * @param callback
 */
export function createScript(url, callback) {
  const oScript = document.createElement('script')
  oScript.type = 'text/javascript'
  oScript.async = true
  oScript.src = url

  /**
   * IE6/7/8                -- onreadystatechange
   * IE9/10                 -- onreadystatechange, onload
   * Firefox/Chrome/Opera   -- onload
   */

  const isIE = !-[1,] // eslint-disable-line
  if (isIE) {
    // 判断IE8及以下浏览器
    oScript.onreadystatechange = function () {
      if (this.readyState === 'loaded' || this.readyState === 'complete') {
        callback && callback()
      }
    }
  } else {
    // IE9及以上浏览器，Firefox，Chrome，Opera
    oScript.onload = function () {
      callback && callback()
    }
  }

  document.body.appendChild(oScript)
}

/**
 * 判断平台
 * @return {String} 平台
 */
export function detectOS() {
  const ua = navigator.userAgent.toLowerCase()

  if (/MicroMessenger/i.test(ua)) {
    return 'weixin'
  } else if (/iPhone|iPad|iPod|iOS/i.test(ua)) {
    return 'ios'
  } else if (/Android/i.test(ua)) {
    return 'android'
  } else {
    return 'other'
  }
}

//身份证号获取出生年月
export function getBirthdayByIdNO (id_card_no){
  var date_of_birth = "";
  if (id_card_no.length==18) {
    date_of_birth = id_card_no.substr(6,8);
    return date_of_birth.replace(/(.{4})(.{2})/,"$1-$2-");
  }else if(id_card_no.length==15){
    date_of_birth = "19"+date_of_birth.substr(6,6);
    return date_of_birth.replace(/(.{4})(.{2})/,"$1-$2-");
  }else{
    return date_of_birth;
  }
}

//身份证获取性别
export function getSexByIdNO(id_card_no){
  if (id_card_no.length==18) {
    return id_card_no.charAt(16)%2==0?"FEMALE":"MALE";
  }else if(id_card_no.length==15){
    return id_card_no.charAt(14)%2==0?"FEMALE":"MALE";
  }else{
    return "";
  }
}

// 计算年龄
export function getAge(id_card_no) {
  var len = (id_card_no + "").length;
  if (len == 0) {
    return 0;
  } else {
    if ((len != 15) && (len != 18))
    {
      return 0;
    }
  }
  var strBirthday = "";
  if (len == 18)
  {
    strBirthday = id_card_no.substr(6, 4) + "/" + id_card_no.substr(10, 2) + "/" + id_card_no.substr(12, 2);
  }
  if (len == 15) {
    strBirthday = "19" + id_card_no.substr(6, 2) + "/" + id_card_no.substr(8, 2) + "/" + id_card_no.substr(10, 2);
  }
  //时间字符串里，必须是“/”
  var birthDate = new Date(strBirthday);
  var nowDateTime = new Date();
  var age = nowDateTime.getFullYear() - birthDate.getFullYear();
  //再考虑月、天的因素;.getMonth()获取的是从0开始的，这里进行比较，不需要加1
  if (nowDateTime.getMonth() < birthDate.getMonth() || (nowDateTime.getMonth() == birthDate.getMonth() && nowDateTime.getDate() < birthDate.getDate())) {
    age--;
  }
  return age;
}
